==> component-office-1.2.17-20191023.123652-4-sources.jar: com/bxm/component/office/excel/format/impl/MoneyCellConverter.java <==
package com.bxm.component.office.excel.format.impl;

import com.bxm.component.office.excel.format.config.CellTypeEnum;
import com.bxm.newidea.component.tools.NumberUtils;
import org.apache.poi.hssf.usermodel.HSSFCell;
import org.apache.poi.hssf.usermodel.HSSFCellStyle;
import org.apache.poi.ss.usermodel.Cell;
import org.apache.poi.ss.usermodel.CellStyle;

import java.math.BigDecimal;

/**
 * 功能说明：<br/>
 * 金额类型转换器
 * <br/>
 * 开发人员：liuj(liujia1@strongit.com.cn)<br/>
 * 开发时间：2016年3月3日<br/>
 */
public class MoneyCellConverter extends AbstractCellConverter {

    @Override
    public int getOrder() {
        return 0;
    }

    @Override
    public boolean isMatch(CellTypeEnum cellType) {
        return CellTypeEnum.MONEY.equals(cellType);
    }

    @Override
    public void setValue() {
        Object value = getSetValue();
        if (null == value) {
            value = "0";
        }
        getCell().setCellType(HSSFCell.CELL_TYPE_NUMERIC);

        CellStyle cellStyle = getCell().getCellStyle();
        cellStyle.setAlignment(HSSFCellStyle.ALIGN_RIGHT);

        getCell().setCellValue(NumberUtils.format(NumberUtils.parseToDecimal(value.toString())));
    }

    @Override
    public Object getValue() {
        int cellType = getCellType();
        Double value = null;

        if (cellType == Cell.CELL_TYPE_STRING) {
            value = NumberUtils.parseToDouble(getCell().getStringCellValue());
        } else if (cellType == Cell.CELL_TYPE_NUMERIC) {
            value = getCell().getNumericCellValue();
        }

        Class<?> clasz = getValueClass();

        if (null == value) {
            return 0;
        }
        if (BigDecimal.class.equals(clasz)) {
            return new BigDecimal(value);
        } else if (Double.class.equals(clasz) || double.class.equals(clasz)) {
            return value;
        } else if (Float.class.equals(clasz) || float.class.equals(clasz)) {
            return new Float(value);
        } else if (Integer.class.equals(clasz) || int.class.equals(clasz)) {
            return value.intValue();
        } else if (Short.class.equals(clasz) || short.class.equals(clasz)) {
            return value.shortValue();
        } else if (Long.class.equals(clasz) || long.class.equals(clasz)) {
            return value.longValue();
        }
        return value;
    }

}

==> component-office-2.1.0-20210607.130215-10-sources.jar: com/bxm/component/office/excel/format/impl/MoneyCellConverter.java <==
package com.bxm.component.office.excel.format.impl;

import com.bxm.component.office.excel.format.config.CellTypeEnum;
import com.bxm.newidea.component.tools.NumberUtils;
import org.apache.poi.ss.usermodel.CellStyle;
import org.apache.poi.ss.usermodel.CellType;
import org.apache.poi.ss.usermodel.HorizontalAlignment;

import java.math.BigDecimal;

/**
 * 功能说明：<br/>
 * 金额类型转换器
 * <br/>
 * 开发人员：liuj(liujia1@strongit.com.cn)<br/>
 * 开发时间：2016年3月3日<br/>
 */
public class MoneyCellConverter extends AbstractCellConverter {

    @Override
    public int getOrder() {
        return 0;
    }

    @Override
    public boolean isMatch(CellTypeEnum cellType) {
        return CellTypeEnum.MONEY.equals(cellType);
    }

    @Override
    public void setValue() {
        Object value = getSetValue();
        if (null == value) {
            value = "0";
        }
        getCell().setCellType(CellType.NUMERIC);

        CellStyle cellStyle = getCell().getCellStyle();
        cellStyle.setAlignment(HorizontalAlignment.RIGHT);

        getCell().setCellValue(NumberUtils.format(NumberUtils.parseToDecimal(value.toString())));
    }

    @Override
    public Object getValue() {
        CellType cellType = getCellType();
        Double value = null;

        if (cellType == CellType.STRING) {
            value = NumberUtils.parseToDouble(getCell().getStringCellValue());
        } else if (cellType == CellType.NUMERIC) {
            value = getCell().getNumericCellValue();
        }

        Class<?> clasz = getValueClass();

        if (null == value) {
            return 0;
        }
        if (BigDecimal.class.equals(clasz)) {
            return new BigDecimal(value);
        } else if (Double.class.equals(clasz) || double.class.equals(clasz)) {
            return value;
        } else if (Float.class.equals(clasz) || float.class.equals(clasz)) {
            return new Float(value);
        } else if (Integer.class.equals(clasz) || int.class.equals(clasz)) {
            return value.intValue();
        } else if (Short.class.equals(clasz) || short.class.equals(clasz)) {
            return value.shortValue();
        } else if (Long.class.equals(clasz) || long.class.equals(clasz)) {
            return value.longValue();
        }
        return value;
    }

}
